]> git.cameronkatri.com Git - mandoc.git/blobdiff - out.h
No longer use names that only occur in the SYNOPSIS section as names
[mandoc.git] / out.h
diff --git a/out.h b/out.h
index 7cb95a7d9b66829acdb952ed4904e6a75826bd71..f6aceb9c13f4d7b814ab413a027a63eea5f30322 100644 (file)
--- a/out.h
+++ b/out.h
@@ -1,4 +1,4 @@
-/*     $Id: out.h,v 1.28 2017/06/08 12:54:58 schwarze Exp $ */
+/*     $Id: out.h,v 1.31 2017/06/27 18:25:02 schwarze Exp $ */
 /*
  * Copyright (c) 2009, 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
  * Copyright (c) 2014, 2017 Ingo Schwarze <schwarze@openbsd.org>
@@ -33,6 +33,7 @@ enum  roffscale {
 struct roffcol {
        size_t           width; /* width of cell */
        size_t           decimal; /* decimal position in cell */
+       size_t           spacing; /* spacing after the column */
        int              flags; /* layout flags, see tbl_cell */
 };
 
@@ -41,14 +42,16 @@ struct      roffsu {
        double            scale;
 };
 
+typedef        size_t  (*tbl_sulen)(const struct roffsu *, void *);
 typedef        size_t  (*tbl_strlen)(const char *, void *);
 typedef        size_t  (*tbl_len)(size_t, void *);
 
 struct rofftbl {
+       tbl_sulen        sulen; /* calculate scaling unit length */
        tbl_strlen       slen; /* calculate string length */
        tbl_len          len; /* produce width of empty space */
        struct roffcol  *cols; /* master column specifiers */
-       void            *arg; /* passed to slen and len */
+       void            *arg; /* passed to sulen, slen, and len */
 };
 
 #define        SCALE_VS_INIT(p, v) \
@@ -66,4 +69,4 @@ struct        tbl_span;
 
 const char      *a2roffsu(const char *, struct roffsu *, enum roffscale);
 void             tblcalc(struct rofftbl *tbl,
-                       const struct tbl_span *, size_t);
+                       const struct tbl_span *, size_t, size_t);